@@ -5,7 +5,9 @@ WriteOpResult = TypedDict('WriteOpResult', ok=bool, n=int, ids=Iterable[str])
 ParameterKind = type(Parameter.POSITIONAL_OR_KEYWORD)  # to get the enum type
 
 Params = Iterable[Parameter]
-HasParams = Union[Iterable[Parameter], Mapping[str, Parameter], Signature, Callable]
+HasParams = Union[
+    Iterable[Parameter], Mapping[str, Parameter], Signature, Callable
+]
 
 # short hands for Parameter kinds
 PK = Parameter.POSITIONAL_OR_KEYWORD
